# bagheera-python [![Build Status](https://travis-ci.com/bagheera-lang/bagheera-python.svg?branch=main)](https://travis-ci.com/bagheera-lang/bagheera-python) [![Documentation Status](https://readthedocs.org/projects/bagheera-python/badge/?version=main)](https://bagheera-python.readthedocs.io/en/main/?badge=main) [![Coverage Status](https://coveralls.io/repos/github/bagheera-lang/bagheera-python/badge.svg?branch=main)](https://coveralls.io/github/bagheera-lang/bagheera-python?branch=main) [![Downloads](https://img.shields.io/pypi/dm/bagheera.svg)](https://pypi.org/project/bagheera/)


An python implementation of the bagheera programming langugage
